@@ -10,7 +10,13 @@ use vars qw($VERSION $logger);
 # it's a problem with who's cleanup() get called
 use base qw(MyCPAN::App::BackPAN::Indexer MyCPAN::Indexer);
 
-$VERSION = '1.28_11';
+use Cwd qw(cwd);
+use File::Basename qw(dirname);
+use File::Path qw(mkpath);
+use File::Temp qw(tempdir);
+use File::Spec::Functions qw(catfile rel2abs);
+
+$VERSION = '1.27';
 
 =head1 NAME
 
@@ -32,6 +38,7 @@ It runs through the indexing and prints a report at the end of the run.
 
 =cut
 
+use Carp qw(croak);
 use Cwd  qw(cwd);
 
 use Log::Log4perl;
@@ -73,7 +80,7 @@ sub examine_dist_steps
 	);
 	}
 
-=item find_module_techniques
+=item find_modules_techniques
 
 Returns the list of techniques that C<find_modules> should use
 to look for Perl module files. See the documentation in
@@ -83,33 +90,7 @@ C<MyCPAN::Indexer::find_modules>.
 
 sub find_module_techniques
 	{
-	my( $self ) = @_;
-
-=pod
-
-Save this feature for another time
-
-	my $config = $self->get_coordinator->get_config;
-
-	if( my @techniques = $config->get( 'find_module_techniques' ) )
-		{
-		$logger->debug( "Using techniques [@techniques] to find modules" );
-
-		@techniques = map {
-			my $can =  $self->can( $_ );
-			$logger->warn( "The technique [$_] is unknown" )
-				unless $can;
-			$can ? [ $_, 'Technique $_ specified by config' ] : ();
-			} @techniques;
-
-		return \@techniques;
-		}
-
-=cut
-
-
 	(
-	[ 'look_in_cwd_and_lib',       "Guessed from looking in lib/"      ],
 	[ 'look_in_lib',               "Guessed from looking in lib/"      ],
 	[ 'look_in_cwd',               "Guessed from looking in cwd"       ],
 	[ 'look_in_meta_yml_provides', "Guessed from looking in META.yml"  ],
@@ -193,7 +174,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2008-2010, brian d foy, All Rights Reserved.
+Copyright (c) 2008-2009, brian d foy, All Rights Reserved.
 
 You may redistribute this under the same terms as Perl itself.
 
